diff --git a/docs/reference/gio/gio-sections.txt b/docs/reference/gio/gio-sections.txt
index 6dbe76719..b136cdcc0 100644
--- a/docs/reference/gio/gio-sections.txt
+++ b/docs/reference/gio/gio-sections.txt
@@ -1830,7 +1830,6 @@ g_unix_socket_address_get_type
gnativesocketaddress
GNativeSocketAddress
GNativeSocketAddress
-GNativeSocketAddressType
g_native_socket_address_new
GNativeSocketAddressClass
@@ -2268,6 +2267,7 @@ G_SOCKET_LISTENER
G_SOCKET_LISTENER_CLASS
G_SOCKET_LISTENER_GET_CLASS
G_TYPE_SOCKET_LISTENER
+G_TYPE_SOCKET_LISTENER_EVENT
GSocketListenerPrivate
g_socket_listener_get_type
@@ -4517,4 +4517,6 @@ G_WIN32_REGISTRY_KEY_CLASS
G_IS_WIN32_REGISTRY_KEY
G_IS_WIN32_REGISTRY_KEY_CLASS
G_WIN32_REGISTRY_KEY_GET_CLASS
+G_TYPE_WIN32_REGISTRY_SUBKEY_ITER
+G_TYPE_WIN32_REGISTRY_VALUE_ITER
diff --git a/docs/reference/glib/glib-sections.txt b/docs/reference/glib/glib-sections.txt
index d5fa3fe99..718ac6268 100644
--- a/docs/reference/glib/glib-sections.txt
+++ b/docs/reference/glib/glib-sections.txt
@@ -2456,6 +2456,7 @@ g_string_equal
g_string_append_c_inline
+g_autoptr_cleanup_gstring_free
diff --git a/gio/gnativesocketaddress.c b/gio/gnativesocketaddress.c
index b63001de2..c1c175669 100644
--- a/gio/gnativesocketaddress.c
+++ b/gio/gnativesocketaddress.c
@@ -132,10 +132,10 @@ g_native_socket_address_init (GNativeSocketAddress *address)
/**
* g_native_socket_address_new:
- * @address: a #GNativeAddress
- * @port: a port number
+ * @native: a native address object
+ * @len: the length of @native, in bytes
*
- * Creates a new #GNativeSocketAddress for @address and @port.
+ * Creates a new #GNativeSocketAddress for @native and @len.
*
* Returns: a new #GNativeSocketAddress
*
diff --git a/gio/gwin32registrykey.c b/gio/gwin32registrykey.c
index f71772869..69cd9ed47 100644
--- a/gio/gwin32registrykey.c
+++ b/gio/gwin32registrykey.c
@@ -1496,12 +1496,11 @@ expand_value (gunichar2 *value,
* g_win32_registry_value_iter_get_data_w:
* @iter: (in) (transfer none): a #GWin32RegistryValueIter
* @auto_expand: (in): %TRUE to automatically expand G_WIN32_REGISTRY_VALUE_EXPAND_STR to
- * G_WIN32_REGISTRY_VALUE_STR.
+ * G_WIN32_REGISTRY_VALUE_STR
* @value_data: (out callee-allocates) (optional) (transfer none): Pointer to a
- * location to store the data of the value (in UTF-16, if it's a string).
- * @value_data_len: (out) (optional): Pointer to a location to store the size
- * of @value_data, in bytes (including any NUL-terminators, if it's a
- * string).
+ * location to store the data of the value (in UTF-16, if it's a string)
+ * @value_data_size: (out) (optional): Pointer to a location to store the size
+ * of @value_data, in bytes (including any NUL-terminators, if it's a string).
* %NULL if length is not needed.
* @error: (nullable): a pointer to %NULL #GError, or %NULL
*
@@ -1563,12 +1562,13 @@ g_win32_registry_value_iter_get_data_w (GWin32RegistryValueIter *iter,
/**
* g_win32_registry_value_iter_get_data:
* @iter: (in) (transfer none): a #GWin32RegistryValueIter
+ * @auto_expand: (in): %TRUE to automatically expand G_WIN32_REGISTRY_VALUE_EXPAND_STR to
+ * G_WIN32_REGISTRY_VALUE_STR
* @value_data: (out callee-allocates) (optional) (transfer none): Pointer to a
- * location to store the data of the value (in UTF-8, if it's a string).
+ * location to store the data of the value (in UTF-8, if it's a string)
* @value_data_size: (out) (optional): Pointer to a location to store the length
- * of @value_data, in bytes (including any NUL-terminators, if it's a
- * string).
- * %NULL if length is not needed.
+ * of @value_data, in bytes (including any NUL-terminators, if it's a string).
+ * %NULL if length is not needed
* @error: (nullable): a pointer to %NULL #GError, or %NULL
*
* Stores the data of the value currently being iterated over in @value_data,
@@ -2135,7 +2135,7 @@ key_changed (PVOID closure,
* @key: (in) (transfer none): a #GWin32RegistryKey
* @watch_children: (in) %TRUE also watch the children of the @key, %FALSE
* to watch the key only.
- * @change_flags: (in): specifies the types of changes to watch for.
+ * @watch_flags: (in): specifies the types of changes to watch for.
* @callback: (in) (nullable): a function to invoke when a change occurs.
* @user_data: (in) (nullable): a pointer to pass to @callback on invocation.
* @error: (nullable): a pointer to %NULL #GError, or %NULL
diff --git a/glib/gasyncqueue.c b/glib/gasyncqueue.c
index 84d2f7504..aff2f02fe 100644
--- a/glib/gasyncqueue.c
+++ b/glib/gasyncqueue.c
@@ -788,7 +788,7 @@ g_async_queue_sort_unlocked (GAsyncQueue *queue,
/**
* g_async_queue_remove:
* @queue: a #GAsyncQueue
* @data: the @data to remove from the @queue
*
* Remove an item from the queue.
*
@@ -798,15 +798,15 @@ g_async_queue_sort_unlocked (GAsyncQueue *queue,
*/
gboolean
g_async_queue_remove (GAsyncQueue *queue,
- gpointer data)
+ gpointer item)
{
gboolean ret;
g_return_val_if_fail (queue != NULL, FALSE);
- g_return_val_if_fail (data != NULL, FALSE);
+ g_return_val_if_fail (item != NULL, FALSE);
g_mutex_lock (&queue->mutex);
- ret = g_async_queue_remove_unlocked (queue, data);
+ ret = g_async_queue_remove_unlocked (queue, item);
g_mutex_unlock (&queue->mutex);
return ret;
@@ -815,7 +815,7 @@ g_async_queue_remove (GAsyncQueue *queue,
/**
* g_async_queue_remove_unlocked:
* @queue: a #GAsyncQueue
* @data: the @data to remove from the @queue
*
* Remove an item from the queue.
*
@@ -827,20 +827,20 @@ g_async_queue_remove (GAsyncQueue *queue,
*/
gboolean
g_async_queue_remove_unlocked (GAsyncQueue *queue,
- gpointer data)
+ gpointer item)
{
g_return_val_if_fail (queue != NULL, FALSE);
- g_return_val_if_fail (data != NULL, FALSE);
+ g_return_val_if_fail (item != NULL, FALSE);
- return g_queue_remove (&queue->queue, data);
+ return g_queue_remove (&queue->queue, item);
}
/**
* g_async_queue_push_front:
* @queue: a #GAsyncQueue
* @data: @data to push into the @queue
*
* Pushes the @data into the @queue. @data must not be %NULL.
* In contrast to g_async_queue_push(), this function
* pushes the new item ahead of the items already in the queue,
* so that it will be the next one to be popped off the queue.
@@ -849,22 +849,22 @@ g_async_queue_remove_unlocked (GAsyncQueue *queue,
*/
void
g_async_queue_push_front (GAsyncQueue *queue,
- gpointer data)
+ gpointer item)
{
g_return_if_fail (queue != NULL);
- g_return_if_fail (data != NULL);
+ g_return_if_fail (item != NULL);
g_mutex_lock (&queue->mutex);
- g_async_queue_push_front_unlocked (queue, data);
+ g_async_queue_push_front_unlocked (queue, item);
g_mutex_unlock (&queue->mutex);
}
/**
* g_async_queue_push_front_unlocked:
* @queue: a #GAsyncQueue
* @data: @data to push into the @queue
*
* Pushes the @data into the @queue. @data must not be %NULL.
* In contrast to g_async_queue_push_unlocked(), this function
* pushes the new item ahead of the items already in the queue,
* so that it will be the next one to be popped off the queue.
@@ -875,12 +875,12 @@ g_async_queue_push_front (GAsyncQueue *queue,
*/
void
g_async_queue_push_front_unlocked (GAsyncQueue *queue,
- gpointer data)
+ gpointer item)
{
g_return_if_fail (queue != NULL);
- g_return_if_fail (data != NULL);
+ g_return_if_fail (item != NULL);
- g_queue_push_tail (&queue->queue, data);
+ g_queue_push_tail (&queue->queue, item);
if (queue->waiting_threads > 0)
g_cond_signal (&queue->cond);
}
@@ -788,7 +788,7 @@ g_async_queue_sort_unlocked (GAsyncQueue *queue,
* g_async_queue_remove:
* @queue: a #GAsyncQueue
- * @data: the @data to remove from the @queue
+ * @item: the data to remove from the @queue
*
* Remove an item from the queue.
@@ -815,7 +815,7 @@ g_async_queue_remove (GAsyncQueue *queue,
* g_async_queue_remove_unlocked:
* @queue: a #GAsyncQueue
- * @data: the @data to remove from the @queue
+ * @item: the data to remove from the @queue
*
* Remove an item from the queue.
@@ -827,20 +827,20 @@ g_async_queue_remove (GAsyncQueue *queue,
* g_async_queue_push_front:
* @queue: a #GAsyncQueue
- * @data: @data to push into the @queue
+ * @item: data to push into the @queue
*
@@ -827,20 +827,20 @@ g_async_queue_remove (GAsyncQueue *queue,
*
- * Pushes the @data into the @queue. @data must not be %NULL.
+ * Pushes the @item into the @queue. @item must not be %NULL.
* In contrast to g_async_queue_push(), this function
* pushes the new item ahead of the items already in the queue,
@@ -849,22 +849,22 @@ g_async_queue_remove_unlocked (GAsyncQueue *queue,
* g_async_queue_push_front_unlocked:
* @queue: a #GAsyncQueue
- * @data: @data to push into the @queue
+ * @item: data to push into the @queue
*
@@ -849,22 +849,22 @@ g_async_queue_remove_unlocked (GAsyncQueue *queue,
*
- * Pushes the @data into the @queue. @data must not be %NULL.
+ * Pushes the @item into the @queue. @item must not be %NULL.
* In contrast to g_async_queue_push_unlocked(), this function
* pushes the new item ahead of the items already in the queue,